@@ -14,7 +14,7 @@ import pyfiglet
 log = None
 def print_title(title, logger_name):
     global log
-    title = pyfiglet.figlet_format('DCCE CLI', font='slant')
+    title = pyfiglet.figlet_format(title, font='slant')
     print(f'[blue]{title}[/blue]')
     FORMAT = "%(message)s"
     logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", handlers=[RichHandler(rich_tracebacks=True, markup=True)])
@@ -42,11 +42,11 @@ class pyclibase(object):
             # THIS TRY, EXCEPT IS ADDED AS PRINT LINE MIGHT FAIL RANDOMLY FOR UNICODEENCODEERROR
             try:
                 line = ps.stdout.readline().decode('ISO-8859-1')
-                self.logger.info(line)
+                log.info(line)
                 #sys.stdout.write(line)
                 #sys.stdout.flush()
             except UnicodeEncodeError as err:
-                self.logger.error("\nException occured while trying to print line.\n{0}".format(err))
+                log.error("\nException occured while trying to print line.\n{0}".format(err))
             if retcode is not None and line == '':
                 break
 
@@ -57,6 +57,6 @@ class pyclibase(object):
         try:
             output = subprocess.check_output(cmd, timeout=60*60, shell=True, stderr=subprocess.DEVNULL)
         except Exception as generic_exception:
-            self.logger.error('Caught Exception: {}'.format(generic_exception))
+            log.error('Caught Exception: {}'.format(generic_exception))
 
         return output
